==> linshare-core-1.7.9-src.tar.bz2: src/main/java/org/linagora/linshare/core/domain/entities/LdapUserProvider.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.domain.entities;

public class LdapUserProvider {

	/**
	 * Database persistence identifier
	 */
	private long persistenceId;
	
	public long getPersistenceId() {
		return persistenceId;
	}

	public void setPersistenceId(long persistenceId) {
		this.persistenceId = persistenceId;
	}
	
	private String baseDn;

	private LDAPConnection ldapconnexion;

	private DomainPattern pattern;

	public LdapUserProvider() {
	}
	

	public LdapUserProvider(String baseDn, LDAPConnection ldapconnexion,
			DomainPattern pattern) {
		super();
		this.baseDn = baseDn;
		this.ldapconnexion = ldapconnexion;
		this.pattern = pattern;
	}

	public DomainPattern getPattern() {
		return pattern;
	}

	public void setPattern(DomainPattern pattern) {
		this.pattern = pattern;
	}

	public String getBaseDn() {
		return baseDn;
	}

	public void setBaseDn(String baseDn) {
		this.baseDn = baseDn;
	}

	public void setLdapconnexion(LDAPConnection ldapconnexion) {
		this.ldapconnexion = ldapconnexion;
	}

	public LDAPConnection getLdapconnexion() {
		return ldapconnexion;
	}

	@Override
	public String toString() {
		return "LdapUserProvider : " + baseDn + " : " + ldapconnexion.getIdentifier() + " : " + pattern.getIdentifier();
	}
}

==> linshare-core-1.9.2-src.tar.bz2: src/main/java/org/linagora/linshare/core/domain/entities/LdapUserProvider.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.domain.entities;

import java.util.UUID;

import org.linagora.linshare.core.facade.webservice.admin.dto.LDAPUserProviderDto;

public class LdapUserProvider extends UserProvider {

	private String baseDn;

	private LdapConnection ldapConnection;

	private UserLdapPattern pattern;

	protected LdapUserProvider() {
	}

	public LdapUserProvider(String baseDn, LdapConnection ldapConnection,
			UserLdapPattern pattern) {
		super();
		this.uuid = UUID.randomUUID().toString();
		this.baseDn = baseDn;
		this.ldapConnection = ldapConnection;
		this.pattern = pattern;
	}

	public UserLdapPattern getPattern() {
		return pattern;
	}

	public void setPattern(UserLdapPattern pattern) {
		this.pattern = pattern;
	}

	public String getBaseDn() {
		return baseDn;
	}

	public void setBaseDn(String baseDn) {
		this.baseDn = baseDn;
	}

	public void setLdapConnection(LdapConnection ldapConnection) {
		this.ldapConnection = ldapConnection;
	}

	public LdapConnection getLdapConnection() {
		return ldapConnection;
	}

	@Override
	public String toString() {
		return "LdapUserProvider [baseDn=" + baseDn + ", uuid=" + uuid + "]";
	}

	@Override
	public LDAPUserProviderDto toLDAPUserProviderDto() {
		LDAPUserProviderDto l = new LDAPUserProviderDto();
		l.setUuid(uuid);
		l.setBaseDn(baseDn);
		l.setUserLdapPatternUuid(this.pattern.getUuid());
		l.setLdapConnectionUuid(this.ldapConnection.getUuid());
		return l;
	}
}
